/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.archives.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.archives.entity.TEmployeeContractInfo;
import com.yifu.cloud.plus.v1.yifu.archives.service.TEmployeeContractInfoService;
import com.yifu.cloud.plus.v1.yifu.common.core.util.ErrorMessage;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpHeaders;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 员工合同
 *
 * @author hgw
 * @date 2022-06-29 20:45:22
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/temployeecontractinfo")
@Tag(name = "员工合同管理")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class TEmployeeContractInfoController {

	private final TEmployeeContractInfoService tEmployeeContractInfoService;

	/**
	 * 分页查询
	 *
	 * @param page                  分页对象
	 * @param tEmployeeContractInfo 员工合同
	 * @return
	 */
	@Operation(summary = "分页查询", description = "分页查询")
	@GetMapping("/page")
	public R gettemployeecontractinfoPage(Page<TEmployeeContractInfo> page, TEmployeeContractInfo tEmployeeContractInfo) {
		return new R<>(tEmployeeContractInfoService.getTEmployeeContractInfoPage(page, tEmployeeContractInfo));
	}


	/**
	 * 通过id查询员工合同
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询：hasPermission('temployeecontractinfo_get')")
	@GetMapping("/{id}")
	public R getById(@PathVariable("id") String id) {
		return R.ok(tEmployeeContractInfoService.getById(id));
	}

	/**
	 * 新增员工合同
	 *
	 * @param tEmployeeContractInfo 员工合同
	 * @return R
	 */
	@Operation(summary = "新增员工合同", description = "新增员工合同：hasPermission('temployeecontractinfo_add')")
	@SysLog("新增员工合同")
	@PostMapping
	@PreAuthorize("@pms.hasPermission('temployeecontractinfo_add')")
	public R<List<ErrorMessage>> save(@RequestBody TEmployeeContractInfo tEmployeeContractInfo) {
		return tEmployeeContractInfoService.saveNewContract(tEmployeeContractInfo);
	}

	/**
	 * 修改员工合同
	 *
	 * @param tEmployeeContractInfo 员工合同
	 * @return R
	 */
	@Operation(summary = "修改员工合同", description = "修改员工合同：hasPermission('temployeecontractinfo_edit')")
	@SysLog("修改员工合同")
	@PutMapping
	@PreAuthorize("@pms.hasPermission('temployeecontractinfo_edit')")
	public R updateById(@RequestBody TEmployeeContractInfo tEmployeeContractInfo) {
		return R.ok(tEmployeeContractInfoService.updateById(tEmployeeContractInfo));
	}

	/**
	 * 通过id删除员工合同
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除员工合同", description = "通过id删除员工合同：hasPermission('temployeecontractinfo_del')")
	@SysLog("通过id删除员工合同")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('temployeecontractinfo_del')")
	public R removeById(@PathVariable String id) {
		return R.ok(tEmployeeContractInfoService.removeById(id));
	}

}
